glfw-Toolbox
==============

| Written for Python 3.X

Source repo on `github <https://github.com/ppizarror/glfw-toolbox>`__

Introduction
------------

glfwToolbox that contains several functions to init OpenGL, create models,
load textures, create vectors, load OBJ, GEMH files, etc.

Install Instructions
--------------------

glfw-Toolbox can be downloaded via pip. Simply run pip install
glfw-toolbox.

Dependencies
~~~~~~~~~~~~

This library is dependant on the following

- numpy
- PyOpenGL
- glfw
- PIL
- matplotlib

Contributors
------------

Ideas and contributions are always welcome. Any found bugs or
enhancement suggestions should be posted in the issues tab.

Aditional Information
---------------------

Licensing
~~~~~~~~~

| This project is distributed using the MIT license.
| For more licensing information read LICENSE on github.

Contact Info:
~~~~~~~~~~~~~

This project does not have a mailing list and so the issues tab should
be the first point of contact if wishing to discuss the project. If you
have questions that you do not feel are relavent to the issues tab or
just want to let me know what you think about the library, feel free to
email me.

Email: pablo.pizarro@ing.uchile.cl